==> open-cluster-management-observability-model-5.12.2-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/AdvancedConfigBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AdvancedConfigBuilder extends io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.AdvancedConfigFluentImpl<io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.AdvancedConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.AdvancedConfig,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.AdvancedConfigBuilder>{
  public AdvancedConfigBuilder() {
    this(false);
  }
  public AdvancedConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new AdvancedConfig(), validationEnabled);
  }
  public AdvancedConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.AdvancedConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public AdvancedConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.AdvancedConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AdvancedConfig(), validationEnabled);
  }
  public AdvancedConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.AdvancedConfigFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.AdvancedConfig instance) {
    this(fluent, instance, false);
  }
  public AdvancedConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.AdvancedConfigFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.AdvancedConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAlertmanager(instance.getAlertmanager()); 
    fluent.withCompact(instance.getCompact()); 
    fluent.withGrafana(instance.getGrafana()); 
    fluent.withObservatoriumAPI(instance.getObservatoriumAPI()); 
    fluent.withObservatoriumConfig(instance.getObservatoriumConfig()); 
    fluent.withQuery(instance.getQuery()); 
    fluent.withQueryFrontend(instance.getQueryFrontend()); 
    fluent.withQueryFrontendMemcached(instance.getQueryFrontendMemcached()); 
    fluent.withRbacQueryProxy(instance.getRbacQueryProxy()); 
    fluent.withReceive(instance.getReceive()); 
    fluent.withRetentionConfig(instance.getRetentionConfig()); 
    fluent.withRule(instance.getRule()); 
    fluent.withStore(instance.getStore()); 
    fluent.withStoreMemcached(instance.getStoreMemcached()); 
    this.validationEnabled = validationEnabled; 
  }
  public AdvancedConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.AdvancedConfig instance) {
    this(instance,false);
  }
  public AdvancedConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.AdvancedConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAlertmanager(instance.getAlertmanager()); 
    this.withCompact(instance.getCompact()); 
    this.withGrafana(instance.getGrafana()); 
    this.withObservatoriumAPI(instance.getObservatoriumAPI()); 
    this.withObservatoriumConfig(instance.getObservatoriumConfig()); 
    this.withQuery(instance.getQuery()); 
    this.withQueryFrontend(instance.getQueryFrontend()); 
    this.withQueryFrontendMemcached(instance.getQueryFrontendMemcached()); 
    this.withRbacQueryProxy(instance.getRbacQueryProxy()); 
    this.withReceive(instance.getReceive()); 
    this.withRetentionConfig(instance.getRetentionConfig()); 
    this.withRule(instance.getRule()); 
    this.withStore(instance.getStore()); 
    this.withStoreMemcached(instance.getStoreMemcached()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.AdvancedConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.AdvancedConfig build() {
    AdvancedConfig buildable = new AdvancedConfig(fluent.getAlertmanager(),fluent.getCompact(),fluent.getGrafana(),fluent.getObservatoriumAPI(),fluent.getObservatoriumConfig(),fluent.getQuery(),fluent.getQueryFrontend(),fluent.getQueryFrontendMemcached(),fluent.getRbacQueryProxy(),fluent.getReceive(),fluent.getRetentionConfig(),fluent.getRule(),fluent.getStore(),fluent.getStoreMemcached());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AdvancedConfigBuilder that = (AdvancedConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-observability-model-6.0.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/AdvancedConfigBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AdvancedConfigBuilder extends AdvancedConfigFluentImpl<AdvancedConfigBuilder> implements VisitableBuilder<AdvancedConfig,AdvancedConfigBuilder>{
  public AdvancedConfigBuilder() {
    this(false);
  }
  public AdvancedConfigBuilder(Boolean validationEnabled) {
    this(new AdvancedConfig(), validationEnabled);
  }
  public AdvancedConfigBuilder(AdvancedConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public AdvancedConfigBuilder(AdvancedConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AdvancedConfig(), validationEnabled);
  }
  public AdvancedConfigBuilder(AdvancedConfigFluent<?> fluent,AdvancedConfig instance) {
    this(fluent, instance, false);
  }
  public AdvancedConfigBuilder(AdvancedConfigFluent<?> fluent,AdvancedConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAlertmanager(instance.getAlertmanager()); 
    fluent.withCompact(instance.getCompact()); 
    fluent.withGrafana(instance.getGrafana()); 
    fluent.withObservatoriumAPI(instance.getObservatoriumAPI()); 
    fluent.withObservatoriumConfig(instance.getObservatoriumConfig()); 
    fluent.withQuery(instance.getQuery()); 
    fluent.withQueryFrontend(instance.getQueryFrontend()); 
    fluent.withQueryFrontendMemcached(instance.getQueryFrontendMemcached()); 
    fluent.withRbacQueryProxy(instance.getRbacQueryProxy()); 
    fluent.withReceive(instance.getReceive()); 
    fluent.withRetentionConfig(instance.getRetentionConfig()); 
    fluent.withRule(instance.getRule()); 
    fluent.withStore(instance.getStore()); 
    fluent.withStoreMemcached(instance.getStoreMemcached()); 
    this.validationEnabled = validationEnabled; 
  }
  public AdvancedConfigBuilder(AdvancedConfig instance) {
    this(instance,false);
  }
  public AdvancedConfigBuilder(AdvancedConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAlertmanager(instance.getAlertmanager()); 
    this.withCompact(instance.getCompact()); 
    this.withGrafana(instance.getGrafana()); 
    this.withObservatoriumAPI(instance.getObservatoriumAPI()); 
    this.withObservatoriumConfig(instance.getObservatoriumConfig()); 
    this.withQuery(instance.getQuery()); 
    this.withQueryFrontend(instance.getQueryFrontend()); 
    this.withQueryFrontendMemcached(instance.getQueryFrontendMemcached()); 
    this.withRbacQueryProxy(instance.getRbacQueryProxy()); 
    this.withReceive(instance.getReceive()); 
    this.withRetentionConfig(instance.getRetentionConfig()); 
    this.withRule(instance.getRule()); 
    this.withStore(instance.getStore()); 
    this.withStoreMemcached(instance.getStoreMemcached()); 
    this.validationEnabled = validationEnabled; 
  }
  AdvancedConfigFluent<?> fluent;
  Boolean validationEnabled;
  public AdvancedConfig build() {
    AdvancedConfig buildable = new AdvancedConfig(fluent.getAlertmanager(),fluent.getCompact(),fluent.getGrafana(),fluent.getObservatoriumAPI(),fluent.getObservatoriumConfig(),fluent.getQuery(),fluent.getQueryFrontend(),fluent.getQueryFrontendMemcached(),fluent.getRbacQueryProxy(),fluent.getReceive(),fluent.getRetentionConfig(),fluent.getRule(),fluent.getStore(),fluent.getStoreMemcached());
    return buildable;
  }
  
}
